pub enum MeshAttributeError {
MissingAttribute(&'static str),
UnexpectedFormat(&'static str, VertexFormat),
}Expand description
Generic error for when a mesh was expected to have a certain attribute with a certain format.
Variants
MissingAttribute(&'static str)
UnexpectedFormat(&'static str, VertexFormat)